#[non_exhaustive]pub struct DataBitTiming {
pub prescaler: NonZeroU16,
pub seg1: NonZeroU8,
pub seg2: NonZeroU8,
pub sync_jump_width: NonZeroU8,
pub transceiver_delay_compensation: bool,
pub tdc_offset: u8,
pub tdc_filter_window_length: u8,
}Expand description
Configures the data bit timings for the FdCan Variable Bitrates. This is not used when frame_transmit is set to anything other than AllowFdCanAndBRS.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prescaler: NonZeroU16The value by which the oscillator frequency is divided to generate the bit time quanta. The bit time is built up from a multiple of this quanta. Valid values for the Baud Rate Prescaler are 1 to 31.
seg1: NonZeroU8Valid values are 1 to 31.
seg2: NonZeroU8Valid values are 1 to 15.
sync_jump_width: NonZeroU8Must always be smaller than DTSEG2, valid values are 1 to 15.
transceiver_delay_compensation: boolTransceiver Delay Compensation enabled
tdc_offset: u8Transmitter delay compensation offset, valid values are 0 to 63.
tdc_filter_window_length: u8Transmitter delay compensation filter window length, valid values are 0 to 63.